==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/he-IL/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'אשר מחיקה גורפת של נכסים',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'עיין בנכסים למחיקה בכמות גדולה בהמשך. לאחר המחיקה, ניתן לשחזר נכסים אלה, אך הם לא יהיו משויכים עוד עם משתמשים שאליהם הם מוקצים כעת.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'אתה עומד למחוק את הנכסים: asset_count.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'עדכון גורפת נכסים',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר נכסים בבת אחת. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'הוצא אל',
    'checkout_date'		=> 'תבדוק את התאריך',
    'checkin_date'		=> 'תאריך הגעה',
    'checkout_to'		=> 'צא אל',
    'cost'				=> 'עלות הרכישה',
    'create'			=> 'צור נכס',
    'date'				=> 'תאריך רכישה',
    'depreciation'	    => 'פְּחָת',
    'depreciates_on'	=> 'פוחתת ב',
    'default_location'	=> 'מיקום ברירת המחדל',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'תאריך EOL',
    'eol_rate'			=> 'שער EOL',
    'expected_checkin'  => 'תאריך הצ\'קין הצפוי',
    'expires'			=> 'יפוג',
    'fully_depreciated'	=> 'פוחת לחלוטין',
    'help_checkout'		=> 'אם ברצונך להקצות נכס זה באופן מיידי, בחר באפשרות "מוכן לפריסה" מרשימת הסטטוס שלמעלה.',
    'mac_address'		=> 'כתובת MAC',
    'manufacturer'		=> 'יַצרָן',
    'model'				=> 'דֶגֶם',
    'months'			=> 'חודשים',
    'name'				=> 'שם הנכס',
    'notes'				=> 'הערות',
    'order'				=> 'מספר הזמנה',
    'qr'				=> 'קוד QR',
    'requestable'		=> 'משתמשים רשאים לבקש את הנכס',
    'select_statustype'	=> 'בחר סוג סטטוס',
    'serial'			=> 'סידורי',
    'status'			=> 'סטָטוּס',
    'tag'				=> 'תג נכס',
    'update'			=> 'עדכון נכס',
    'warranty'			=> 'אַחֲרָיוּת',
        'warranty_expires'		=> 'תפוגת האחריות',
    'years'				=> 'שנים',
    'asset_location' => 'עדכן מיקום הנכס',
    'asset_location_update_default_current' => 'עדכן מיקומים',
    'asset_location_update_default' => 'עדכן מיקום ברירת מחדל',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'הנכס הזה לא זמין. לא ניתן לספק ללקוח.',
    'asset_deployable' => 'הנכס זמין. ניתן לשייך למיקום.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/he-IL/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'אשר מחיקה גורפת של נכסים',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'עיין בנכסים למחיקה בכמות גדולה בהמשך. לאחר המחיקה, ניתן לשחזר נכסים אלה, אך הם לא יהיו משויכים עוד עם משתמשים שאליהם הם מוקצים כעת.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'אתה עומד למחוק את הנכסים: asset_count.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'עדכון גורפת נכסים',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר נכסים בבת אחת. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'בדגמים', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'הוצא אל',
    'checkout_date'		=> 'תבדוק את התאריך',
    'checkin_date'		=> 'תאריך הגעה',
    'checkout_to'		=> 'צא אל',
    'cost'				=> 'עלות הרכישה',
    'create'			=> 'צור נכס',
    'date'				=> 'תאריך רכישה',
    'depreciation'	    => 'פְּחָת',
    'depreciates_on'	=> 'פוחתת ב',
    'default_location'	=> 'מיקום ברירת המחדל',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'תאריך EOL',
    'eol_rate'			=> 'שער EOL',
    'expected_checkin'  => 'תאריך הצ\'קין הצפוי',
    'expires'			=> 'יפוג',
    'fully_depreciated'	=> 'פוחת לחלוטין',
    'help_checkout'		=> 'אם ברצונך להקצות נכס זה באופן מיידי, בחר באפשרות "מוכן לפריסה" מרשימת הסטטוס שלמעלה.',
    'mac_address'		=> 'כתובת MAC',
    'manufacturer'		=> 'יַצרָן',
    'model'				=> 'דֶגֶם',
    'months'			=> 'חודשים',
    'name'				=> 'שם הנכס',
    'notes'				=> 'הערות',
    'order'				=> 'מספר הזמנה',
    'qr'				=> 'קוד QR',
    'requestable'		=> 'משתמשים רשאים לבקש את הנכס',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'בחר סוג סטטוס',
    'serial'			=> 'סידורי',
    'status'			=> 'סטָטוּס',
    'tag'				=> 'תג נכס',
    'update'			=> 'עדכון נכס',
    'warranty'			=> 'אַחֲרָיוּת',
        'warranty_expires'		=> 'תפוגת האחריות',
    'years'				=> 'שנים',
    'asset_location' => 'עדכן מיקום הנכס',
    'asset_location_update_default_current' => 'עדכן מיקומים',
    'asset_location_update_default' => 'עדכן מיקום ברירת מחדל',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'הנכס הזה לא זמין. לא ניתן לספק ללקוח.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'הנכס זמין. ניתן לשייך למיקום.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
